Troubleshooting — Django Grappelli 2.3.9 documentation

### Navigation

- index
- next |
- previous |
- Django Grappelli 2.3.9 documentation »

# Troubleshooting

Sometimes you might have a problem installing/using Grappelli.

## Check your setup

First, please check if the problem is caused by your setup.

- Read Quick start guide and Customization.
- Check if the static/media-files are served correctly.
- Make sure you have removed all customized admin templates from all locations in TEMPLATE_DIRS paths or check that these templates are compatible with Grappelli.

## Check issues

If your setup is fine, please check if your problem is a known issue.

- Read Django Issues in order to see if your problem is indeed related to Grappelli.
- Take a look at all Grappelli Issues (incuding closed) and search the Grappelli Google-Group.

## Add a ticket

If you think you’ve found a bug, please add a ticket.

- Try to describe your problem as precisely as possible.
- Tell us what you did in order to solve the problem.
- Tell us what version of Grappelli you are using.
- Tell us what version of Django you are using.
- Please do NOT add tickets if you´re having problems with serving static/media-files (because this is not related to Grappelli).
- Please do NOT add tickets referring to Djangos trunk version.
- At best: add a patch.

Note

Be aware that we may close issues not following these guidlines without further notifications.

### Navigation

- index
- next |
- previous |
- Django Grappelli 2.3.9 documentation »